@@ -118,5 +118,14 @@ output_info
 #/usr/share/java/SimplyHTMLHelp.jar:\
 #/usr/share/java/SimplyHTML.jar:"
 
-_debug "Calling: '${JAVACMD} -jar /usr/share/java/SimplyHTML.jar com.lightdev.app.shtm.App $@'."
-"${JAVACMD}" -jar /usr/share/java/SimplyHTML.jar com.lightdev.app.shtm.App "$@"
+MNEMONICSETTER_JAR=$(find /usr/share/maven-repo/org/dpolivaev/mnemonicsetter/mnemonicsetter/ -name "mnemonicsetter-*.jar" | sort -V | tail -n 1)
+
+if [ ! -f "$MNEMONICSETTER_JAR" ]; then
+    _error "MnemonicSetter JAR not found in Maven repository."
+    exit 1
+fi
+
+CLASSPATH="/usr/share/java/SimplyHTML.jar:$MNEMONICSETTER_JAR"
+
+_debug "Calling: '${JAVACMD} -cp $CLASSPATH com.lightdev.app.shtm.App $@'."
+"${JAVACMD}" -cp "$CLASSPATH" com.lightdev.app.shtm.App "$@"
